<?php

/**
 * @file
 * bynder/includes/bynder.formatters.inc
 * Formatters for Media: Bynder.
 */

/**
 * Implements hook_file_formatter_info().
 * $info: Array of information on file formatters exposed by hook_file_formatter_info() implementations.
 */
function bynder_orbit_file_formatter_info_alter(&$info)
{
    $info['file_image'] = array(
        'label' => t('Bynder Orbit Preview Image'),
        'file types' => array(
            'image'
        ),
        'default settings' => array(
            'image_style' => ''
        ),
        'view callback' => 'bynder_orbit_file_formatter_image_view',
        'settings callback' => 'bynder_orbit_file_formatter_image_settings',
        'mime types' => array(
            'image/bynder_orbit'
        )
    );

    return $info;
}

/**
 * Format image view.
 */
function bynder_orbit_file_formatter_image_view($file, $display, $langcode)
{
    $scheme = file_uri_scheme($file->uri);
    if ($scheme == 'orbit') {
        $wrapper = file_stream_wrapper_get_instance_by_uri($file->uri);
        $image_style = $display['settings']['image_style'];
        $element = array(
            '#theme' => 'image',
            '#path' => $wrapper->getWebImagePath($file->filename, $image_style),
            '#style_name' => $image_style,
            '#alt' => isset($file->override['attributes']['alt']) ? $file->override['attributes']['alt'] : $file->filename,
        );
        return $element;
    }
}

/**
 * Implements hook_file_formatter_FORMATTER_settings().
 */
function bynder_orbit_file_formatter_image_settings($form, &$form_state, $settings)
{
    $element = array();
    $element['image_style'] = array(
        '#title' => t('Image style'),
        '#type' => 'select',
        '#options' => image_style_options(false),
        '#default_value' => $settings['image_style'],
        '#empty_option' => t('None (original image)')
    );
    return $element;
}

function bynder_orbit_field_info_alter(&$info)
{
    $info['image']['default widget'] = 'orbit';
}

/**
 * Implements hook_field_formatter_info().
 * Add a new formatter for field type "image"
 */
function bynder_orbit_field_formatter_info()
{
    return array(
        'bynder_orbit_absolute_url' => array(
            'label' => t('Absolute URL'),
            'field types' => array('image'),
            'multiple values' => FIELD_BEHAVIOR_DEFAULT,
            'settings' => array(
                'tooltip' => t('Bynder function that returns the image URL.'),
                'image_style' => 'bynder_drupal_example'
            )
        )
    );
}

/**
 * Implements hook_field_formatter_settings_form().
 */
function bynder_orbit_field_formatter_settings_form($field, $instance, $view_mode, $form, &$form_state)
{
    $settings = $instance['display'][$view_mode]['settings'];
    $options = array();

    foreach (image_styles() as $image_style) {
        $options[$image_style['name']] = $image_style['label'];
    }

    $element = array();

    $element['image_style'] = array(
        '#type' => 'select',
        '#title' => t('Image Style'),
        '#description' => t('Select your Image Style, for which to get the absolute URL'),
        '#default_value' => $settings['image_style'],
        '#options' => $options
    );

    return $element;
}

/**
 * Implements hook_field_formatter_settings_summary.
 * The summary for the "manage display view"
 */
function bynder_orbit_field_formatter_settings_summary($field, $instance, $view_mode)
{
    $display = $instance['display'][$view_mode];
    $settings = $display['settings'];
    $summary = t('Return the absolute URL with <b> @style </b> Image Style',
        array('@style' => $settings['image_style'])
    );

    return $summary;
}
